@@ -1,5 +1,7 @@
 #![deny(dead_code)]
 #![deny(unused_imports)]
+#![allow(unknown_lints)]
+#![feature(loop_break_value)]
 #![feature(alloc_system)]
 extern crate alloc_system;
 extern crate arrayvec;
@@ -27,7 +29,7 @@ use std::sync::{Arc, Mutex};
 use std::sync::mpsc::channel;
 
 use arguments::Args;
-use threads::pipe::State;
+use threads::pipe::disk::State;
 use tokenizer::{Token, TokenErr, tokenize};
 
 /// Coercing the `command` `String` into a `&'static str` is required to share it among all threads.
@@ -42,7 +44,7 @@ unsafe fn leak_command(comm: String) -> &'static str {
 /// Determines if a shell is required or not for execution
 fn shell_required(arguments: &[Token]) -> bool {
     for token in arguments {
-        if let &Token::Argument(ref arg) = token {
+        if let Token::Argument(ref arg) = *token {
             if arg.contains(';') || arg.contains('&') || arg.contains('|') {
                 return true
             }
@@ -80,7 +82,7 @@ fn main() {
     let mut args = Args::new();
     let mut comm = String::with_capacity(128);
     let inputs = init::parse(&mut args, &mut comm, &unprocessed_path);
-    
+
     // Coerce the `comm` `String` into a `&'static str` so that it may be shared by all threads.
     // This is safe because the original `comm` may no longer be modified due to shadowing rules.
     // It is also safe because `comm` lives to the end of the program.
@@ -103,8 +105,8 @@ fn main() {
     // Determines if a shell is required or not
     if !shell_required(&args.arguments) {
         args.flags &= 255 ^ arguments::SHELL_ENABLED;
-    } else {
-        if dash_exists() { args.flags |= arguments::DASH_EXISTS; }
+    } else if dash_exists() {
+        args.flags |= arguments::DASH_EXISTS;
     }
 
     let shared_input = Arc::new(Mutex::new(inputs));
